import { __extends } from 'tslib';
import { Component, EventEmitter, Input, Output, Injectable, NgModule } from '@angular/core';
import { NgbDateAdapter, NgbModule } from '@ng-bootstrap/ng-bootstrap';
import { FormsModule } from '@angular/forms';
import { BrowserModule } from '@angular/platform-browser';
import { ClickOutsideModule } from 'ng4-click-outside';

var NgbeDatetimePickerComponent = /** @class */ (function () {
    function NgbeDatetimePickerComponent() {
        this.valueChange = new EventEmitter();
        this.showPopup = false;
        this.popupClosed = new EventEmitter();
        this.showSeconds = true;
        this.localValue = null;
        this.localDate = null;
        this.localTime = null;
    }
    NgbeDatetimePickerComponent.prototype.ngOnInit = function () {
    };
    NgbeDatetimePickerComponent.prototype.ngOnChanges = function (changes) {
        if (!this.nowButton) {
            this.nowButton = { show: true, label: 'Now', cssClass: 'btn btn-secondary btn-sm' };
        }
        if (!this.clearButton) {
            this.clearButton = { show: true, label: 'Clear', cssClass: 'btn btn-secondary btn-sm' };
        }
        if (!this.closeButton) {
            this.closeButton = { show: true, label: 'Close', cssClass: 'btn btn-secondary btn-sm' };
        }
        if (typeof this.value === 'string') {
            if (!isNaN(new Date(this.value).getTime())) {
                this.localValue = new Date(this.value);
            }
        }
        else if (this.value) {
            this.localValue = this.value;
        }
        this.localDate = this.localValue;
        this.localTime = this.convertDateToNgbTimeStruct(this.localValue);
    };
    NgbeDatetimePickerComponent.prototype.offClick = function () {
        this.showPopup = false;
        this.popupClosed.emit(true);
    };
    NgbeDatetimePickerComponent.prototype.onNow = function () {
        this.localValue = new Date();
        this.onPickerChange();
    };
    NgbeDatetimePickerComponent.prototype.onPickerChange = function () {
        this.valueChange.emit(this.localValue);
    };
    NgbeDatetimePickerComponent.prototype.toggle = function () {
        if (this.showPopup) {
            this.showPopup = false;
        }
        else {
            this.showPopup = true;
        }
    };
    NgbeDatetimePickerComponent.prototype.updateDate = function () {
        this.localValue.setFullYear(this.localDate.getFullYear());
        this.localValue.setMonth(this.localDate.getMonth());
        this.localValue.setDate(this.localDate.getDate());
        this.valueChange.emit(this.localValue.toISOString());
    };
    NgbeDatetimePickerComponent.prototype.updateTime = function () {
        this.convertNgbTimeStructToDate(this.localValue);
        this.valueChange.emit(this.localValue.toISOString());
    };
    NgbeDatetimePickerComponent.prototype.convertNgbTimeStructToDate = function (date) {
        date.setHours(this.localTime.hour);
        date.setMinutes(this.localTime.minute);
        date.setSeconds(this.localTime.second);
    };
    NgbeDatetimePickerComponent.prototype.convertDateToNgbTimeStruct = function (date) {
        return {
            hour: date.getHours(),
            minute: date.getMinutes(),
            second: date.getSeconds()
        };
    };
    return NgbeDatetimePickerComponent;
}());
NgbeDatetimePickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngbe-datetime-picker',
                template: "<div class=\"dropdown\" *ngIf=\"showPopup\">\n  <ul class=\"dropdown-menu text-center\" role=\"menu\" [ngClass]=\"{ 'show': showPopup === true }\"\n      (clickOutside)=\"offClick($event)\" [delayClickOutsideInit]=\"true\">\n    <li class=\"my-3 mx-2\">\n      <ngb-datepicker [(ngModel)]=\"localDate\" (ngModelChange)=\"updateDate()\"></ngb-datepicker>\n      <ngb-timepicker [(ngModel)]=\"localTime\" [seconds]=\"showSeconds\" (ngModelChange)=\"updateTime()\"></ngb-timepicker>\n    </li>\n    <li class=\"mx-3 mb-2\">\n      <div class=\"row\">\n        <div class=\"btn-group col\">\n          <button class=\"w-100\" type=\"button\" (click)=\"onNow()\"\n                  *ngIf=\"nowButton.show\"\n                  [ngClass]=\"nowButton.cssClass\">{{nowButton.label}}\n          </button>\n        </div>\n        <div class=\"btn-group col\">\n          <button class=\"w-100\" type=\"button\" (click)=\"offClick()\"\n                  *ngIf=\"closeButton.show\"\n                  [ngClass]=\"closeButton.cssClass\">{{closeButton.label}}\n          </button>\n        </div>\n      </div>\n    </li>\n  </ul>\n</div>\n",
                styles: ["::ng-deep ngb-timepicker .ngb-tp{\n  -webkit-box-pack:center;\n      -ms-flex-pack:center;\n          justify-content:center; }\n"]
            },] },
];
NgbeDatetimePickerComponent.ctorParameters = function () { return []; };
NgbeDatetimePickerComponent.propDecorators = {
    "value": [{ type: Input },],
    "valueChange": [{ type: Output },],
    "showPopup": [{ type: Input },],
    "popupClosed": [{ type: Output },],
    "showSeconds": [{ type: Input },],
    "nowButton": [{ type: Input },],
    "clearButton": [{ type: Input },],
    "closeButton": [{ type: Input },],
};
var NgbDateNativeAdapter = /** @class */ (function (_super) {
    __extends(NgbDateNativeAdapter, _super);
    function NgbDateNativeAdapter() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NgbDateNativeAdapter.prototype.fromModel = function (date) {
        return (date && date.getFullYear) ? { year: date.getFullYear(), month: date.getMonth() + 1, day: date.getDate() } : null;
    };
    NgbDateNativeAdapter.prototype.toModel = function (date) {
        return date ? new Date(Date.UTC(date.year, date.month - 1, date.day)) : null;
    };
    return NgbDateNativeAdapter;
}(NgbDateAdapter));
NgbDateNativeAdapter.decorators = [
    { type: Injectable },
];
NgbDateNativeAdapter.ctorParameters = function () { return []; };
var NgbeDatetimePickerModule = /** @class */ (function () {
    function NgbeDatetimePickerModule() {
    }
    return NgbeDatetimePickerModule;
}());
NgbeDatetimePickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgbeDatetimePickerComponent],
                imports: [FormsModule, BrowserModule, ClickOutsideModule, NgbModule],
                providers: [
                    { provide: NgbDateAdapter, useClass: NgbDateNativeAdapter },
                ],
                exports: [NgbeDatetimePickerComponent]
            },] },
];
NgbeDatetimePickerModule.ctorParameters = function () { return []; };

export { NgbeDatetimePickerModule, NgbeDatetimePickerComponent, NgbDateNativeAdapter as ɵa };
//# sourceMappingURL=ngbe-datetime-picker.js.map
